# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import attachment
from . import mail
from . import message_reaction
from . import portal
from . import thread
from . import web
